@@ -747,7 +747,7 @@ f13_icorr (float **P, int Ng)
     hy -= py[i] * log10 (py[i] + EPSILON);
   }
 /*  fprintf(stderr,"hx=%f\thxy2=%f\n",hx,hxy2); */
-  return (sqrt (abs (1 - exp (-2.0 * (hxy2 - hxy)))));
+  return (sqrt (fabs (1 - exp (-2.0 * (hxy2 - hxy)))));
 }
 
 static float 
