@@ -66,7 +66,7 @@ validate_input(const struct pam pam1, const struct pam pam2) {
 static void
 psnr_color(tuple const tuple1, tuple const tuple2,
            double * const ySqDiffP, 
-           double * const crSqDiffP, double * const cbSqDiffP) {
+           double * const cbSqDiffP, double * const crSqDiffP) {
 
     double y1, y2, cb1, cb2, cr1, cr2;
     
