@@ -596,9 +596,9 @@ compute_depth(xelval const input_maxval, unsigned int * const bitspersampleP,
 -----------------------------------------------------------------------------*/
     unsigned int const bitsRequiredByMaxval = pm_maxvaltobits(input_maxval);
 
-    if (bitsRequiredByMaxval <= 2)
+    if (bitsRequiredByMaxval <= 1)
         *bitspersampleP = 1;
-    else if (bitsRequiredByMaxval > 2 && bitsRequiredByMaxval <= 4)
+    else if (bitsRequiredByMaxval > 1 && bitsRequiredByMaxval <= 4)
         *bitspersampleP = 4;
     else 
         *bitspersampleP = 8;
@@ -622,11 +622,15 @@ convert_row(struct pam * const pamP, tuple * const tuplerow,
 
     for (plane = 0; plane < pamP->depth; ++plane) {
         unsigned int col;
-        for (col= 0; col < pamP->width; ++col) 
+        for (col= 0; col < pamP->width; ++col) {
+            sample const scaledSample = 
+                pnm_scalesample(tuplerow[col][plane], pamP->maxval, ps_maxval);
+
             if ( rle )
-                rleputxelval(tuplerow[col][plane]);
+                rleputxelval(scaledSample);
             else
-                putxelval(tuplerow[col][plane]);
+                putxelval(scaledSample);
+        }
         for (col = 0; col < padright; ++col)
             if (rle)
                 rleputxelval(0);
