@@ -250,24 +250,36 @@ enum postscript_language {COMMON_POSTSCRIPT, ENCAPSULATED_POSTSCRIPT};
 
 static enum postscript_language
 language_declaration(const char input_filespec[], int const verbose) {
-
-    FILE *infile;
+/*----------------------------------------------------------------------------
+  Return the Postscript language in which the file declares it is written.
+  (Except that if the file is on Standard Input or doesn't validly declare
+  a languages, just say it is Common Postscript).
+-----------------------------------------------------------------------------*/
     enum postscript_language language;
-    char line[80];
 
-    infile = pm_openr(input_filespec);
-
-    if (fgets(line, sizeof(line), infile) == NULL)
+    if (strcmp(input_filespec, "-") == 0)
+        /* Can't read stdin, because we need it to remain positioned for the 
+           Ghostscript interpreter to read it.
+        */
         language = COMMON_POSTSCRIPT;
     else {
-        const char eps_header[] = "%!PS-Adobe EPSF-3.0";
+        FILE *infile;
+        char line[80];
 
-        if (strncmp(line, eps_header, sizeof(eps_header)) == 0)
-            language = ENCAPSULATED_POSTSCRIPT;
-        else
+        infile = pm_openr(input_filespec);
+
+        if (fgets(line, sizeof(line), infile) == NULL)
             language = COMMON_POSTSCRIPT;
+        else {
+            const char eps_header[] = "%!PS-Adobe EPSF-3.0";
+            
+            if (strncmp(line, eps_header, sizeof(eps_header)) == 0)
+                language = ENCAPSULATED_POSTSCRIPT;
+            else
+                language = COMMON_POSTSCRIPT;
+        }
+        fclose(infile);
     }
-    fclose(infile);
     if (verbose)
         pm_message("language is %s",
                    language == ENCAPSULATED_POSTSCRIPT ?
