@@ -134,7 +134,7 @@ parse_command_line(int argc, char ** argv,
 
 
 static void
-PutByte(FILE *fp, char v)
+PutByte(FILE *fp, unsigned char v)
 {
         if (putc(v, fp) == EOF)
         {
@@ -364,7 +364,8 @@ BMPwriterow_pallette(FILE *fp, const pixel * const row,
 static int
 BMPwriterow_truecolor(FILE *        const fp, 
                       const pixel * const row, 
-                      unsigned long const cols) {
+                      unsigned long const cols,
+                      pixval        const maxval) {
 /*----------------------------------------------------------------------------
   Write a row of a truecolor BMP image to the file 'fp'.  The row is 
   'row', which is 'cols' columns long.
@@ -386,9 +387,9 @@ BMPwriterow_truecolor(FILE *        const fp,
         
     nbyte = 0;  /* initial value */
     for (col = 0; col < cols; col++) {
-        PutByte(fp, PPM_GETB(row[col]));
-        PutByte(fp, PPM_GETG(row[col]));
-        PutByte(fp, PPM_GETR(row[col]));
+        PutByte(fp, PPM_GETB(row[col]) * 255 / maxval);
+        PutByte(fp, PPM_GETG(row[col]) * 255 / maxval);
+        PutByte(fp, PPM_GETR(row[col]) * 255 / maxval);
         nbyte += 3;
     }
 
@@ -410,7 +411,9 @@ static int
 BMPwritebits(FILE *fp, const unsigned long cx, const unsigned long cy, 
              const enum colortype colortype,
              const unsigned short cBitCount, 
-             const pixel ** const pixels, const colorhash_table cht)
+             const pixel ** const pixels, 
+             const pixval maxval,
+             const colorhash_table cht)
 {
         int             nbyte = 0;
         long            y;
@@ -432,7 +435,7 @@ BMPwritebits(FILE *fp, const unsigned long cx, const unsigned long cy,
                     rc = BMPwriterow_pallette(fp, pixels[y], cx, 
                                               cBitCount, cht);
                 else 
-                    rc = BMPwriterow_truecolor(fp, pixels[y], cx);
+                    rc = BMPwriterow_truecolor(fp, pixels[y], cx, maxval);
 
                 if(rc == -1)
                 {
@@ -460,7 +463,7 @@ static void
 BMPEncode(FILE *fp, const int class, const enum colortype colortype,
           const int bpp,
           const int x, const int y, 
-          const pixel ** const pixels, const int colors, 
+          const pixel ** const pixels, const pixval maxval, const int colors, 
           const colorhash_table cht, 
           const unsigned char R[], const unsigned char G[], 
           const unsigned char B[])
@@ -485,7 +488,7 @@ BMPEncode(FILE *fp, const int class, const enum colortype colortype,
                 pm_error(er_internal, "BMPEncode 1");
         }
 
-        nbyte += BMPwritebits(fp, x, y, colortype, bpp, pixels, cht);
+        nbyte += BMPwritebits(fp, x, y, colortype, bpp, pixels, maxval, cht);
         if(nbyte != BMPlenfile(class, bpp, -1, x, y))
         {
                 pm_error(er_internal, "BMPEncode 2");
@@ -621,7 +624,7 @@ main(int argc, char **argv)
                              &bits_per_pixel);
 
         BMPEncode(stdout, cmdline.class, colortype, bits_per_pixel,
-                  cols, rows, (const pixel**)pixels, colors, cht,
+                  cols, rows, (const pixel**)pixels, maxval, colors, cht,
                   Red, Green, Blue);
 
         if (cht) 
