@@ -1811,7 +1811,7 @@ BiLinearAlloc(Stitcher * me)
     if (LinearAlloc(me) == FALSE) {
         return FALSE;
     }
-    for (num = 8; num > 0; --num) {
+    for (num=0; num<8; num++) {
         me->parms[num] = 0.0;
     }
     /* Unity Transform matrix */
