@@ -25,7 +25,7 @@
 #define FILENAME_LEN 200
 static FILE *psfile = 0;
 char psfname[FILENAME_LEN];
-static FILE *pbmfile = 0;
+static int pbmfile = 0;
 char pbmfname[FILENAME_LEN];
 
 #define BUFFER_SIZE 2048
@@ -242,7 +242,6 @@ cleanup(void)
     unlink(psfname);
   }
   if(pbmfile) {
-    pm_close(pbmfile);
     unlink(pbmfname);
   }
 }
@@ -263,6 +262,7 @@ create_outputfile(struct cmdlineInfo *cmdl)
 
   sprintf(pbmfname, template, getpid(), "pbm");
 
+  pbmfile = 1;
   if(! (com = strdup(gs_command(cmdl))))
     pm_error("Can't allocate ghostscript command");
 
@@ -283,8 +283,6 @@ create_outputfile(struct cmdlineInfo *cmdl)
 
   free(com);
 
-  pbmfile = pm_openw(pbmfname);
-
   com = crop_command();
   if(com) {
     if (cmdl->verbose)
